rm(list=ls(all=TRUE))
set.seed(77)

# CHANGE PATH TO THE REPLICATION FOLDER HERE!
path1 <-"C:/Users/ms3295/Dropbox/Hypo/Work/Current Projects/Polarization and Fraud/Venezuela/Data Analysis/main/REPLICATION/"
setwd(path1)

###############################################################################
# INSTALL PACKAGES THAT WILL BE USED LATER
###############################################################################

install.packages("PACKAGES/arm_1.10-1.tar.gz", repo=NULL, type="source")
install.packages("PACKAGES/boot_1.3-23.tar.gz", repo=NULL, type="source")

library(arm)
library(boot)

###############################################################################
# C.1.1 ACROSS-SUBJECT TREATMENT ASSIGNMENTS
###############################################################################

# LOAD DATA
data <- read.csv(file="DATA/survey.csv", header=TRUE, sep=",")
attach(data)

# TABLE A.1 APPROVAL RATINGS
# COMPARE TREATMENT CONDITIONS: "T1: LD+ v RD+"; "T2: LD- v RD+"; "T3: RD- v RD+";
treat <- ifelse(t1.treat==1 | t1.treat==2, 3, NA) 
treat <- ifelse(t1.treat==3 | t1.treat==4, 1, treat) 
treat <- ifelse(t1.treat==5 | t1.treat==6, 2, treat) 

# APPROVAL OF C1
app.c1 <- ifelse(T2<=10, T2, NA)
round(tapply(app.c1, list(treat), mean, na.rm = TRUE),2)

# APPROVAL OF C2
app.c2 <- ifelse(T3<=10, T3, NA)
round(tapply(app.c2, list(treat), mean, na.rm = TRUE), 2)

# C2-C1
app.diff <- app.c2-app.c1
round(tapply(app.diff, list(treat), mean, na.rm = TRUE), 2)

# CONFIDENCE INTERVALS FOR THE DIFFERENCE
test <- t.test(app.diff[treat==1])
round(test$conf.int, 2)
test <- t.test(app.diff[treat==2])
round(test$conf.int, 2)
test <- t.test(app.diff[treat==3])
round(test$conf.int, 2)


test <- t.test(app.diff[treat==1], app.diff[treat==2])
test 
round(test$conf.int, 2)

test <- t.test(app.diff[treat==3], app.diff[treat==2])
test 
round(test$conf.int, 2)

###############################################################################
# C.1.2 ACROSS-SUBJECT TREATMENT ASSIGNMENTS: HETEROGENEOUS EFFECTS
###############################################################################

lr.self <- ifelse(ID6d<=10, ID6d, NA)

vote.c2 <- ifelse(T1<=2, T1, NA)
vote.c2 <- vote.c2-1

c2s <- c(sum(vote.c2[treat==1], na.rm=TRUE), sum(vote.c2[treat==2], na.rm=TRUE), sum(vote.c2[treat==3], na.rm=TRUE))
totals <- c(sum(!is.na(vote.c2[treat==1])), sum(!is.na(vote.c2[treat==2])), sum(!is.na(vote.c2[treat==3])))

# TABLE A.2: BINOMIAL TEST FOR PROPORTIONS
results <- c()
for (i in 1:10) {
    c2s <- c(sum(vote.c2[lr.self==i & treat==1]==1, na.rm=TRUE), sum(vote.c2[lr.self==i & treat==2]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.self==i & treat==1])), sum(!is.na(vote.c2[lr.self==i & treat==2])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}

# TABLE A.2: OLS
vote <- ifelse(treat!=3, vote.c2, NA)
lr <- as.factor(lr.self)
tr <- ifelse(treat==1, 0, NA)
tr <- ifelse(treat==2, 1, tr)
ols <- lm(vote ~ tr:lr + lr)
ols <- summary(ols)
ols.pvalues <- round(ols$coefficients[11:20,4], 3)

paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], " & ", ols.pvalues, sep="")

# FIGURE A.4
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(-0.1, 1.1), xlab = "Left-Right Self-Placement Scale", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(3, median, labels=c("Median")) 
   axis(2, seq(0,1,.25)) 
   abline(h = 0.5, col='grey60', lty=1, lwd=1)
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,1, c("T1: LD+ v. RD+", "T2: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_4_lr_effects.eps")
plot.it()
dev.off()

# TABLE A.3: T-TEST FOR APPROVAL RATINGS
results <- c()
for (i in 1:10) {
    test <- t.test(app.diff[lr.self==i & treat==1], app.diff[lr.self==i & treat==2])
    result <- c(i, round(test$estimate,3), round(test$estimate[2]-test$estimate[1], 3), round(test$p.value,3), sum(!is.na(app.diff[lr.self==i & treat==1])), sum(!is.na(app.diff[lr.self==i & treat==2])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5] ,sep="")

# FIGURE A.5
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Left-Right Self-Placement Scale", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,4, c("T1: LD+ v. RD+", "T2: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_5_lr_effects_approval.eps")
plot.it()
dev.off()

# TABLE A.4: BINOMIAL TEST FOR PROPORTIONS
results <- c()
for (i in 1:10) {
    c2s <- c(sum(vote.c2[lr.self==i & treat==3]==1, na.rm=TRUE), sum(vote.c2[lr.self==i & treat==2]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.self==i & treat==3])), sum(!is.na(vote.c2[lr.self==i & treat==2])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}

paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep="")

# TABLE A.4: OLS
vote <- ifelse(treat!=1, vote.c2, NA)
lr <- as.factor(lr.self)
tr <- ifelse(treat==3, 0, NA)
tr <- ifelse(treat==2, 1, tr)
ols <- lm(vote ~ tr:lr + lr)
ols <- summary(ols)
ols.pvalues <- round(ols$coefficients[11:20,4], 3)

paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], " & ", ols.pvalues, sep="")

# FIGURE A.6
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(-0.1, 1.1), xlab = "Left-Right Self-Placement Scale", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(3, median, labels=c("Median")) 
   axis(2, seq(0,1,.25)) 
   abline(h = 0.5, col='grey60', lty=1, lwd=1)
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,1, c("T3: RD- v. RD+", "T2: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_6_lr_effects2.eps")
plot.it()
dev.off()

# TABLE A.5: T-TEST FOR APPROVAL RATINGS
results <- c()
for (i in 1:10) {
    test <- t.test(app.diff[lr.self==i & treat==3], app.diff[lr.self==i & treat==2])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.self==i & treat==1])), sum(!is.na(app.diff[lr.self==i & treat==2])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep="")

# FIGURE A.7
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Left-Right Self-Placement Scale", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,6, c("T1: LD+ v. RD+", "T2: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_7_lr_effects_approval2.eps")
plot.it()
dev.off()

# TABLE A.6: BINOMIALS TEST FOR PROPORTIONS
lr.ineq <- ifelse(ID7<=4, ID7, NA)
results <- c()
for (i in 1:4) {
    c2s <- c(sum(vote.c2[lr.ineq==i & treat==1]==1, na.rm=TRUE), sum(vote.c2[lr.ineq==i & treat==2]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.ineq==i & treat==1])), sum(!is.na(vote.c2[lr.ineq==i & treat==2])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
as.matrix(paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep=""))

# TABLE A.6: OLS
vote <- ifelse(treat!=3, vote.c2, NA)
lr <- as.factor(lr.ineq)
tr <- ifelse(treat==1, 0, NA)
tr <- ifelse(treat==2, 1, tr)
ols <- lm(vote ~ tr:lr + lr)
ols <- summary(ols)
ols.pvalues <- round(ols$coefficients[5:8,4], 3)

paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], " & ", ols.pvalues, sep="")

# FUGURE A.8
median <- median(lr.ineq, na.rm=TRUE)
plot.it <- function() {
  par(mar=c(5,6,2,2)+0.1)
  plot(NA, xlim = c(1,4), ylim = c(-0.1, 1.1), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

  axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
  axis(3, 3, labels=c("Median")) 
  axis(2, seq(0,1,.25)) 
  abline(h = 0.5, col='grey60', lty=1, lwd=1)
  abline(v = 3, col='grey60', lty=2, lwd=1)
      
  points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
  lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

  points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
  lines(results[,3], type="l", lty=2, col = "red", lwd=1) 

  legend(1,1, c("T1: LD+ v. RD+", "T2: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red"))   
}

x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_8_ineq_effects.eps")
plot.it()
dev.off()

# TABLE A.7: T-TEST FOR APPROVAL RATINGS
results <- c()
for (i in 1:4) {
    test <- t.test(app.diff[lr.ineq==i & treat==1], app.diff[lr.ineq==i & treat==2])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.ineq==i & treat==1])), sum(!is.na(app.diff[lr.ineq==i & treat==2])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep="")


# FIGURE A.9
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,4), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,4, c("T1: LD+ v. RD+", "T2: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.ineq, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_9_ineq_effects_approval.eps")
plot.it()
dev.off()

# TABLE A.8: BINOMIAL TEST FOR PROPORTIONS
results <- c()
for (i in 1:4) {
    c2s <- c(sum(vote.c2[lr.ineq==i & treat==3]==1, na.rm=TRUE), sum(vote.c2[lr.ineq==i & treat==2]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.ineq==i & treat==3])), sum(!is.na(vote.c2[lr.ineq==i & treat==2])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep="")

# TABLE A.8: OLS
vote <- ifelse(treat!=1, vote.c2, NA)
lr <- as.factor(lr.ineq)
tr <- ifelse(treat==3, 0, NA)
tr <- ifelse(treat==2, 1, tr)
ols <- lm(vote ~ tr:lr + lr)
ols <- summary(ols)
ols.pvalues <- round(ols$coefficients[5:8,4], 3)

paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], " & ", ols.pvalues, sep="")

# FIGRUE A.10
median <- median(lr.ineq, na.rm=TRUE)
plot.it <- function() {
  par(mar=c(5,6,2,2)+0.1)
  plot(NA, xlim = c(1,4), ylim = c(-0.1, 1.1), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

  axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
  axis(3, 3, labels=c("Median")) 
  axis(2, seq(0,1,.25)) 
  abline(h = 0.5, col='grey60', lty=1, lwd=1)
  abline(v = 3, col='grey60', lty=2, lwd=1)
      
  points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
  lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

  points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
  lines(results[,3], type="l", lty=2, col = "red", lwd=1) 

  legend(1,1, c("T3: RD- v. RD+", "T2: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red"))   
}

x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_10_ineq_effects2.eps")
plot.it()
dev.off()

# TABLE A.9: T-TEST FOR APPROVAL RATINGS
results <- c()
for (i in 1:4) {
    test <- t.test(app.diff[lr.ineq==i & treat==3], app.diff[lr.ineq==i & treat==2])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.ineq==i & treat==1])), sum(!is.na(app.diff[lr.ineq==i & treat==2])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep="")

# FIGURE A.11
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,4), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,4, c("T3: RD- v. RD+", "T2: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.ineq, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_11_ineq_effects_approval2.eps")
plot.it()
dev.off()

###############################################################################
# C.1.3 ACCOUNTING FOR ABSTENTIONS
###############################################################################

abstain <- ifelse(T1<=2, 0, NA)
abstain <- ifelse(T1==3 | T1==4, 1, abstain)

abs <- c(sum(abstain[treat==1], na.rm=TRUE), sum(abstain[treat==2], na.rm=TRUE), sum(abstain[treat==3], na.rm=TRUE))
totals <- c(sum(!is.na(abstain[treat==1])), sum(!is.na(abstain[treat==2])), sum(!is.na(abstain[treat==3])))

test <- prop.test(abs[1], totals[1])
test
round(100*test$conf.int, 2)

test <- prop.test(abs[2], totals[2])
test
round(100*test$conf.int, 2)

test <- prop.test(abs[3], totals[3])
test
round(100*test$conf.int, 2)


# FIGURE A.12
abs.plot <- tapply(abstain, list(lr.self ,treat), mean, na.rm = TRUE)
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(-0.05, .55), xlab = "Left-Right Self-Placement Scale", ylab = "% Abstain",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(3, median, labels=c("Median")) 
   axis(2, seq(0,.5,.1)) 
   
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(abs.plot[,1], pch = 19, col = "black", bg = "black", cex=1)
   lines(abs.plot[,1], type="l", lty=1, col = "black", lwd=1) 

   points(abs.plot[,2], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(abs.plot[,2], type="l", lty=2, col = "red", lwd=1) 

   points(abs.plot[,3], pch = 17, col = "blue", bg = "blue", cex=1.2)
   lines(abs.plot[,3], type="l", lty=3, col = "blue", lwd=1) 
   
   legend(7.3, .5, c("T1: LD+ v. RD+", "T2: LD- v. RD+", "T3: RD- v. RD+"), lty=c(1,2,3), lwd=c(2,2,2), pch=c(19,18,17), col=c("black","red","blue")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_12_lr_abstain.eps")
plot.it()
dev.off()

# FIGURE A.13
abs.plot <- tapply(abstain, list(lr.ineq ,treat), mean, na.rm = TRUE)
median <- median(lr.ineq, na.rm=TRUE)
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,4), ylim = c(-0.05, .55), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "% Abstain",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
   axis(3, 3, labels=c("Median")) 
   axis(2, seq(0,.5,.1)) 
   
   abline(v = 3, col='grey60', lty=2, lwd=1)
         
   points(abs.plot[,1], pch = 19, col = "black", bg = "black", cex=1)
   lines(abs.plot[,1], type="l", lty=1, col = "black", lwd=1) 

   points(abs.plot[,2], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(abs.plot[,2], type="l", lty=2, col = "red", lwd=1) 

   points(abs.plot[,3], pch = 17, col = "blue", bg = "blue", cex=1.2)
   lines(abs.plot[,3], type="l", lty=3, col = "blue", lwd=1) 
   
   legend(1,1, c("T1: LD+ v. RD+", "T2: LD- v. RD+", "T3: RD- v. RD+"), lty=c(1,2,3), lwd=c(2,2,2), pch=c(19,18,17), col=c("black","red","blue")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_13_ineq_abstain.eps")
plot.it()
dev.off()

###############################################################################
# C.1.4 WITHIN-SUBJECT TREATMENT ASSIGNMENTS
###############################################################################

# VOTE FOR C2 IN THE CONTROL CONDITION
vote.c <- ifelse(T1==2, 1, NA)
vote.c <- ifelse(T1==1, 0, vote.c)

# VOTE FOR C2 IN TREATMENT (FOLLOW-UP)
vote.t <- ifelse(T1a==2, 1, NA)
vote.t <- ifelse(T1a==1, 0, vote.t)

# W1(t1.treat==3): LD+ v. RD+ -> LD- v. RD+
# W2(t1.treat==4): LD+ v. RD+ -> LD+ v. RD-
# W3(t1.treat==5 | t1.treat==6): LD- v. RD+ -> LD-- v. RD+
# W4(t1.treat==1): RD- v. RD+ -> LD- v. RD+
# W5(t1.treat==2): RD- v. RD+ -> RD- v. LD+

t.cycle <- c("t1.treat==3", "t1.treat==4", "t1.treat==5 | t1.treat==6", "t1.treat==1", "t1.treat==2")

# TABLE A. 11
for (i in t.cycle) {
    
    print("#########################################################################")
    t.cond <- eval(parse(text=i))
    print(i)
    print("#########################################################################")

    # VOTE FOR C2
    n <- length(vote.c[t.cond])
    vote.c2 <- c(vote.c[t.cond], vote.t[t.cond])
    treat <- c(rep(0,n), rep(1,n))
    result <- tapply(vote.c2, list(treat), mean, na.rm = TRUE)
    print(round(100*result, 2))
    print(round(100*(result[2]-result[1]), 2))
    
    c2s <- c(sum(vote.c2[treat==0], na.rm=TRUE), sum(vote.c2[treat==1], na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[treat==0])), sum(!is.na(vote.c2[treat==1])))
    test <- prop.test(c2s, totals)
    print(test)
    print(round(100*test$estimate, 2))
    print(-round(100*test$conf.int, 2))

    test <- prop.test(c2s[1], totals[1])
    print(round(100*test$conf.int, 2))
    test <- prop.test(c2s[2], totals[2])
    print(round(100*test$conf.int, 2))
}

# TABLE A. 12
for (i in t.cycle) {
    
    print("#########################################################################")
    t.cond <- eval(parse(text=i))
    print(i)
    print("#########################################################################")
    
    n <- length(vote.c[t.cond])
    treat <- c(rep(0,n), rep(1,n))
    
    # APPROVAL OF C1 AND C2
    app.c1 <- ifelse(T2<=10, T2, NA)
    app.c2 <- ifelse(T3<=10, T3, NA)
    app.diff <- app.c2-app.c1
    app.diff.c <- app.diff[t.cond]

    app.c1 <- ifelse(T2a<=10, T2a, NA)
    app.c2 <- ifelse(T3a<=10, T3a, NA)
    app.diff <- app.c2-app.c1
    app.diff.t <- app.diff[t.cond]

    app.diff <- c(app.diff.c, app.diff.t)
    result <- tapply(app.diff, list(treat), mean, na.rm = TRUE)
    print(round(result, 2))
    print(round(result[2]-result[1], 2))
    test <- t.test(app.diff[treat==1], app.diff[treat==0])
    print(round(test$conf.int, 2))

    test <- t.test(app.diff[treat==0])
    print(round(test$conf.int, 2))
    test <- t.test(app.diff[treat==1])
    print(round(test$conf.int, 2))
}

###############################################################################
# C.1.5 WITHIN-SUBJECT TREATMENT ASSIGNMENTS: HETEROGENEOUS EFFECTS
###############################################################################

# W1(t1.treat==3): LD+ v. RD+ -> LD- v. RD+
t.cond <- t1.treat==3

vote.c <- ifelse(T1==2, 1, NA)
vote.c <- ifelse(T1==1, 0, vote.c)

vote.t <- ifelse(T1a==2, 1, NA)
vote.t <- ifelse(T1a==1, 0, vote.t)

n <- length(vote.c[t.cond])
vote.c2 <- c(vote.c[t.cond], vote.t[t.cond])
treat <- c(rep(0,n), rep(1,n))

# SUBSET BY LEFT-RIGHT
lr.self <- ifelse(ID6d<=10, ID6d, NA)
lr.self <- c(lr.self[t.cond], lr.self[t.cond])

# TABLE A.13
results <- c()
for (i in 1:10) {
    c2s <- c(sum(vote.c2[lr.self==i & treat==0]==1, na.rm=TRUE), sum(vote.c2[lr.self==i & treat==1]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.self==i & treat==0])), sum(!is.na(vote.c2[lr.self==i & treat==1])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep="")

# FIGURE A.14
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(-0.1, 1.1), xlab = "Left-Right Self-Placement Scale", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(3, median, labels=c("Median")) 
   axis(2, seq(0,1,.25)) 
   abline(h = 0.5, col='grey60', lty=1, lwd=1)
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,1, c("T1: LD+ v. RD+", "W1: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_14_w1_lr_effects.eps")
plot.it()
dev.off()

# TABLE A.14
app.c1 <- ifelse(T2<=10, T2, NA)
app.c2 <- ifelse(T3<=10, T3, NA)
app.diff <- app.c2-app.c1
app.diff.c <- app.diff[t.cond]

app.c1 <- ifelse(T2a<=10, T2a, NA)
app.c2 <- ifelse(T3a<=10, T3a, NA)
app.diff <- app.c2-app.c1
app.diff.t <- app.diff[t.cond]

app.diff <- c(app.diff.c, app.diff.t)

results <- c()
for (i in 1:10) {
    test <- t.test(app.diff[lr.self==i & treat==0], app.diff[lr.self==i & treat==1])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.self==i & treat==0])), sum(!is.na(app.diff[lr.self==i & treat==1])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep="")

# FIGURE A.15
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Left-Right Self-Placement Scale", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,4, c("T1: LD+ v. RD+", "W1: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_15_w1_lr_effects_approval.eps")
plot.it()
dev.off()

# SUBSET BY ATTITUDES TOWARD INEQUALITY
lr.ineq <- ifelse(ID7<=4, ID7, NA)
lr.ineq <- c(lr.ineq[t.cond], lr.ineq[t.cond])

# TABLE A.23
results <- c()
for (i in 1:4) {
    c2s <- c(sum(vote.c2[lr.ineq==i & treat==0]==1, na.rm=TRUE), sum(vote.c2[lr.ineq==i & treat==1]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.ineq==i & treat==0])), sum(!is.na(vote.c2[lr.ineq==i & treat==1])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}
as.matrix(paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep=""))

# FIGURE A.24
plot.it <- function() {
  par(mar=c(5,6,2,2)+0.1)
  plot(NA, xlim = c(1,4), ylim = c(-0.1, 1.1), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

  axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
  axis(3, 3, labels=c("Median")) 
  axis(2, seq(0,1,.25)) 
  abline(h = 0.5, col='grey60', lty=1, lwd=1)
  abline(v = 3, col='grey60', lty=2, lwd=1)
      
  points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
  lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

  points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
  lines(results[,3], type="l", lty=2, col = "red", lwd=1) 

  legend(1,1, c("T1: LD+ v. RD+", "W1: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red"))   
}
median <- median(lr.ineq, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_24_w1_ineq_effects.eps")
plot.it()
dev.off()

# TABLE A.24
tapply(app.diff, list(lr.ineq ,treat), mean, na.rm = TRUE)
tapply(app.diff, list(lr.ineq ,treat), mean, na.rm = TRUE)[,1:2]

results <- c()
for (i in 1:4) {
    test <- t.test(app.diff[lr.ineq==i & treat==0], app.diff[lr.ineq==i & treat==1])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.ineq==i & treat==0])), sum(!is.na(app.diff[lr.ineq==i & treat==1])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}
as.matrix(paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep=""))

# FIGURE A.25
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,4), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,4, c("T1: LD+ v. RD+", "W1: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.ineq, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_25_w1_ineq_effects_approval.eps")
plot.it()
dev.off()

# W2(t1.treat==4): LD+ v. RD+ -> LD+ v. RD-
t.cond <- t1.treat==4
legend.text <- c("T1: LD+ v. RD+", "W2: LD+ v. RD-")

vote.c <- ifelse(T1==2, 1, NA)
vote.c <- ifelse(T1==1, 0, vote.c)

vote.t <- ifelse(T1a==2, 1, NA)
vote.t <- ifelse(T1a==1, 0, vote.t)

n <- length(vote.c[t.cond])
vote.c2 <- c(vote.c[t.cond], vote.t[t.cond])
treat <- c(rep(0,n), rep(1,n))

# SUBSET BY LEFT-RIGHT
lr.self <- ifelse(ID6d<=10, ID6d, NA)
lr.self <- c(lr.self[t.cond], lr.self[t.cond])

# TABLE A.15
results <- c()
for (i in 1:10) {
    c2s <- c(sum(vote.c2[lr.self==i & treat==0]==1, na.rm=TRUE), sum(vote.c2[lr.self==i & treat==1]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.self==i & treat==0])), sum(!is.na(vote.c2[lr.self==i & treat==1])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep="")

# FIGURE A.16
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(-0.1, 1.1), xlab = "Left-Right Self-Placement Scale", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(3, median, labels=c("Median")) 
   axis(2, seq(0,1,.25)) 
   abline(h = 0.5, col='grey60', lty=1, lwd=1)
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,1, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_16_w2_lr_effects.eps")
plot.it()
dev.off()

# TABLE A.16
app.c1 <- ifelse(T2<=10, T2, NA)
app.c2 <- ifelse(T3<=10, T3, NA)
app.diff <- app.c2-app.c1
app.diff.c <- app.diff[t.cond]

app.c1 <- ifelse(T2a<=10, T2a, NA)
app.c2 <- ifelse(T3a<=10, T3a, NA)
app.diff <- app.c2-app.c1
app.diff.t <- app.diff[t.cond]

app.diff <- c(app.diff.c, app.diff.t)

results <- c()
for (i in 1:10) {
    test <- t.test(app.diff[lr.self==i & treat==0], app.diff[lr.self==i & treat==1])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.self==i & treat==0])), sum(!is.na(app.diff[lr.self==i & treat==1])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep="")

# FIGURE A.17
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Left-Right Self-Placement Scale", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,2, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_17_w2_lr_effects_approval.eps")
plot.it()
dev.off()

# SUBSET BY ATTITUDES TOWARD INEQUALITY
lr.ineq <- ifelse(ID7<=4, ID7, NA)
lr.ineq <- c(lr.ineq[t.cond], lr.ineq[t.cond])

# TABLE A.25
results <- c()
for (i in 1:4) {
    c2s <- c(sum(vote.c2[lr.ineq==i & treat==0]==1, na.rm=TRUE), sum(vote.c2[lr.ineq==i & treat==1]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.ineq==i & treat==0])), sum(!is.na(vote.c2[lr.ineq==i & treat==1])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}
as.matrix(paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep=""))

# FIGURE A.26
plot.it <- function() {
  par(mar=c(5,6,2,2)+0.1)
  plot(NA, xlim = c(1,4), ylim = c(-0.1, 1.1), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

  axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
  axis(3, 3, labels=c("Median")) 
  axis(2, seq(0,1,.25)) 
  abline(h = 0.5, col='grey60', lty=1, lwd=1)
  abline(v = 3, col='grey60', lty=2, lwd=1)
      
  points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
  lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

  points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
  lines(results[,3], type="l", lty=2, col = "red", lwd=1) 

  legend(1,1, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.ineq, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_26_w2_ineq_effects.eps")
plot.it()
dev.off()

# TABLE A.27
tapply(app.diff, list(lr.ineq ,treat), mean, na.rm = TRUE)
tapply(app.diff, list(lr.ineq ,treat), mean, na.rm = TRUE)[,1:2]

results <- c()
for (i in 1:4) {
    test <- t.test(app.diff[lr.ineq==i & treat==0], app.diff[lr.ineq==i & treat==1])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.ineq==i & treat==0])), sum(!is.na(app.diff[lr.ineq==i & treat==1])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}
as.matrix(paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep=""))

# FIGURE A.27
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,4), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,2, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.ineq, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_27_w2_ineq_effects_approval.eps")
plot.it()
dev.off()

# W3(t1.treat==5 | t1.treat==6): LD- v. RD+ -> LD-- v. RD+
t.cond <- t1.treat==5 | t1.treat==6
legend.text <- c("T2: LD- v. RD+", "W3: LD-- v. RD+")

vote.c <- ifelse(T1==2, 1, NA)
vote.c <- ifelse(T1==1, 0, vote.c)

vote.t <- ifelse(T1a==2, 1, NA)
vote.t <- ifelse(T1a==1, 0, vote.t)

n <- length(vote.c[t.cond])
vote.c2 <- c(vote.c[t.cond], vote.t[t.cond])
treat <- c(rep(0,n), rep(1,n))

# SUBSET BY LEFT-RIGHT
lr.self <- ifelse(ID6d<=10, ID6d, NA)
lr.self <- c(lr.self[t.cond], lr.self[t.cond])

# TABLE A.17
results <- c()
for (i in 1:10) {
    c2s <- c(sum(vote.c2[lr.self==i & treat==0]==1, na.rm=TRUE), sum(vote.c2[lr.self==i & treat==1]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.self==i & treat==0])), sum(!is.na(vote.c2[lr.self==i & treat==1])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep="")

# FIGURE A.18
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(-0.1, 1.1), xlab = "Left-Right Self-Placement Scale", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(3, median, labels=c("Median")) 
   axis(2, seq(0,1,.25)) 
   abline(h = 0.5, col='grey60', lty=1, lwd=1)
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,1, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_18_w3_lr_effects.eps")
plot.it()
dev.off()

# TABLE A.18
app.c1 <- ifelse(T2<=10, T2, NA)
app.c2 <- ifelse(T3<=10, T3, NA)
app.diff <- app.c2-app.c1
app.diff.c <- app.diff[t.cond]

app.c1 <- ifelse(T2a<=10, T2a, NA)
app.c2 <- ifelse(T3a<=10, T3a, NA)
app.diff <- app.c2-app.c1
app.diff.t <- app.diff[t.cond]

app.diff <- c(app.diff.c, app.diff.t)

results <- c()
for (i in 1:10) {
    test <- t.test(app.diff[lr.self==i & treat==0], app.diff[lr.self==i & treat==1])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.self==i & treat==0])), sum(!is.na(app.diff[lr.self==i & treat==1])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep="")

# FIGURE A.19
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Left-Right Self-Placement Scale", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,4, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_19_w3_lr_effects_approval.eps")
plot.it()
dev.off()

# SUBSET BY ATTITUDES TOWARD INEQUALITY
lr.ineq <- ifelse(ID7<=4, ID7, NA)
lr.ineq <- c(lr.ineq[t.cond], lr.ineq[t.cond])

# TABLE A.27
results <- c()
for (i in 1:4) {
    c2s <- c(sum(vote.c2[lr.ineq==i & treat==0]==1, na.rm=TRUE), sum(vote.c2[lr.ineq==i & treat==1]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.ineq==i & treat==0])), sum(!is.na(vote.c2[lr.ineq==i & treat==1])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}
as.matrix(paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep=""))

# FIGURE A.28
plot.it <- function() {
  par(mar=c(5,6,2,2)+0.1)
  plot(NA, xlim = c(1,4), ylim = c(-0.1, 1.1), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

  axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
  axis(3, 3, labels=c("Median")) 
  axis(2, seq(0,1,.25)) 
  abline(h = 0.5, col='grey60', lty=1, lwd=1)
  abline(v = 3, col='grey60', lty=2, lwd=1)
      
  points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
  lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

  points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
  lines(results[,3], type="l", lty=2, col = "red", lwd=1) 

  legend(1,1, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.ineq, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_28_w3_ineq_effects.eps")
plot.it()
dev.off()

# TABLE A.28
tapply(app.diff, list(lr.ineq ,treat), mean, na.rm = TRUE)
tapply(app.diff, list(lr.ineq ,treat), mean, na.rm = TRUE)[,1:2]

results <- c()
for (i in 1:4) {
    test <- t.test(app.diff[lr.ineq==i & treat==0], app.diff[lr.ineq==i & treat==1])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.ineq==i & treat==0])), sum(!is.na(app.diff[lr.ineq==i & treat==1])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}
as.matrix(paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep=""))

# FIGURE A.29
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,4), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,2, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.ineq, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_29_w3_ineq_effects_approval.eps")
plot.it()
dev.off()

# W4(t1.treat==1): RD- v. RD+ -> LD- v. RD+
t.cond <- t1.treat==1
legend.text <- c("T3: RD- v. RD+", "W4: LD- v. RD+")

vote.c <- ifelse(T1==2, 1, NA)
vote.c <- ifelse(T1==1, 0, vote.c)

vote.t <- ifelse(T1a==2, 1, NA)
vote.t <- ifelse(T1a==1, 0, vote.t)

n <- length(vote.c[t.cond])
vote.c2 <- c(vote.c[t.cond], vote.t[t.cond])
treat <- c(rep(0,n), rep(1,n))

# SUBSET BY LEFT-RIGHT
lr.self <- ifelse(ID6d<=10, ID6d, NA)
lr.self <- c(lr.self[t.cond], lr.self[t.cond])

# TABLE A.19
results <- c()
for (i in 1:10) {
    c2s <- c(sum(vote.c2[lr.self==i & treat==0]==1, na.rm=TRUE), sum(vote.c2[lr.self==i & treat==1]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.self==i & treat==0])), sum(!is.na(vote.c2[lr.self==i & treat==1])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep="")

# FIGURE A.20
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(-0.1, 1.1), xlab = "Left-Right Self-Placement Scale", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(3, median, labels=c("Median")) 
   axis(2, seq(0,1,.25)) 
   abline(h = 0.5, col='grey60', lty=1, lwd=1)
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,1, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_20_w4_lr_effects.eps")
plot.it()
dev.off()

# TABLE A.20
app.c1 <- ifelse(T2<=10, T2, NA)
app.c2 <- ifelse(T3<=10, T3, NA)
app.diff <- app.c2-app.c1
app.diff.c <- app.diff[t.cond]

app.c1 <- ifelse(T2a<=10, T2a, NA)
app.c2 <- ifelse(T3a<=10, T3a, NA)
app.diff <- app.c2-app.c1
app.diff.t <- app.diff[t.cond]

app.diff <- c(app.diff.c, app.diff.t)

results <- c()
for (i in 1:10) {
    test <- t.test(app.diff[lr.self==i & treat==0], app.diff[lr.self==i & treat==1])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.self==i & treat==0])), sum(!is.na(app.diff[lr.self==i & treat==1])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep="")

# FIGURE A.21
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Left-Right Self-Placement Scale", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,4, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_21_w4_lr_effects_approval.eps")
plot.it()
dev.off()

# SUBSET BY ATTITUDES TOWARD INEQUALITY
lr.ineq <- ifelse(ID7<=4, ID7, NA)
lr.ineq <- c(lr.ineq[t.cond], lr.ineq[t.cond])

# TABLE A.29
results <- c()
for (i in 1:4) {
    c2s <- c(sum(vote.c2[lr.ineq==i & treat==0]==1, na.rm=TRUE), sum(vote.c2[lr.ineq==i & treat==1]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.ineq==i & treat==0])), sum(!is.na(vote.c2[lr.ineq==i & treat==1])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}
as.matrix(paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep=""))

# FIGURE A.30
plot.it <- function() {
  par(mar=c(5,6,2,2)+0.1)
  plot(NA, xlim = c(1,4), ylim = c(-0.1, 1.1), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

  axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
  axis(3, 3, labels=c("Median")) 
  axis(2, seq(0,1,.25)) 
  abline(h = 0.5, col='grey60', lty=1, lwd=1)
  abline(v = 3, col='grey60', lty=2, lwd=1)
      
  points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
  lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

  points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
  lines(results[,3], type="l", lty=2, col = "red", lwd=1) 

  legend(1, 1, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.ineq, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_30_w4_ineq_effects.eps")
plot.it()
dev.off()

# TABLE A.30
tapply(app.diff, list(lr.ineq ,treat), mean, na.rm = TRUE)
tapply(app.diff, list(lr.ineq ,treat), mean, na.rm = TRUE)[,1:2]

results <- c()
for (i in 1:4) {
    test <- t.test(app.diff[lr.ineq==i & treat==0], app.diff[lr.ineq==i & treat==1])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.ineq==i & treat==0])), sum(!is.na(app.diff[lr.ineq==i & treat==1])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}
as.matrix(paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep=""))

# FIGURE A.31
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,4), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,2, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.ineq, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_31_w4_ineq_effects_approval.eps")
plot.it()
dev.off()

# W5(t1.treat==2): RD- v. RD+ -> RD- v. LD+
t.cond <- t1.treat==2
legend.text <- c("T3: RD- v. RD+", "W5: RD- v. LD+")

vote.c <- ifelse(T1==2, 1, NA)
vote.c <- ifelse(T1==1, 0, vote.c)

vote.t <- ifelse(T1a==2, 1, NA)
vote.t <- ifelse(T1a==1, 0, vote.t)

n <- length(vote.c[t.cond])
vote.c2 <- c(vote.c[t.cond], vote.t[t.cond])
treat <- c(rep(0,n), rep(1,n))

# SUBSET BY LEFT-RIGHT
lr.self <- ifelse(ID6d<=10, ID6d, NA)
lr.self <- c(lr.self[t.cond], lr.self[t.cond])

# TABLE A.21
results <- c()
for (i in 1:10) {
    c2s <- c(sum(vote.c2[lr.self==i & treat==0]==1, na.rm=TRUE), sum(vote.c2[lr.self==i & treat==1]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.self==i & treat==0])), sum(!is.na(vote.c2[lr.self==i & treat==1])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep="")

# FIGURE A.22
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(-0.1, 1.1), xlab = "Left-Right Self-Placement Scale", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(3, median, labels=c("Median")) 
   axis(2, seq(0,1,.25)) 
   abline(h = 0.5, col='grey60', lty=1, lwd=1)
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,1, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}
median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_22_w5_lr_effects.eps")
plot.it()
dev.off()

# TABLE A.22
app.c1 <- ifelse(T2<=10, T2, NA)
app.c2 <- ifelse(T3<=10, T3, NA)
app.diff <- app.c2-app.c1
app.diff.c <- app.diff[t.cond]

app.c1 <- ifelse(T2a<=10, T2a, NA)
app.c2 <- ifelse(T3a<=10, T3a, NA)
app.diff <- app.c2-app.c1
app.diff.t <- app.diff[t.cond]

app.diff <- c(app.diff.c, app.diff.t)

results <- c()
for (i in 1:10) {
    test <- t.test(app.diff[lr.self==i & treat==0], app.diff[lr.self==i & treat==1])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.self==i & treat==0])), sum(!is.na(app.diff[lr.self==i & treat==1])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}
paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep="")

# FIGURE A.23
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Left-Right Self-Placement Scale", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1, 5, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}
median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_23_w5_lr_effects_approval.eps")
plot.it()
dev.off()

# SUBSET BY ATTITUDES TOWARD INEQUALITY
lr.ineq <- ifelse(ID7<=4, ID7, NA)
lr.ineq <- c(lr.ineq[t.cond], lr.ineq[t.cond])

# TABLE A.31
results <- c()
for (i in 1:4) {
    c2s <- c(sum(vote.c2[lr.ineq==i & treat==0]==1, na.rm=TRUE), sum(vote.c2[lr.ineq==i & treat==1]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.ineq==i & treat==0])), sum(!is.na(vote.c2[lr.ineq==i & treat==1])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}
as.matrix(paste(results[,1], " & ", 100*results[,2], " & (", results[,6], ") & ", 100*results[,3], " & (", results[,7], ") & ", 100*results[,4], " & ", results[,5], sep=""))

# FIGURE A.32
plot.it <- function() {
  par(mar=c(5,6,2,2)+0.1)
  plot(NA, xlim = c(1,4), ylim = c(-0.1, 1.1), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

  axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
  axis(3, 3, labels=c("Median")) 
  axis(2, seq(0,1,.25)) 
  abline(h = 0.5, col='grey60', lty=1, lwd=1)
  abline(v = 3, col='grey60', lty=2, lwd=1)
      
  points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
  lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

  points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
  lines(results[,3], type="l", lty=2, col = "red", lwd=1) 

  legend(1,1, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.ineq, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_32_w5_ineq_effects.eps")
plot.it()
dev.off()

# TABLE A.33
results <- c()
for (i in 1:4) {
    test <- t.test(app.diff[lr.ineq==i & treat==0], app.diff[lr.ineq==i & treat==1])
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), sum(!is.na(app.diff[lr.ineq==i & treat==0])), sum(!is.na(app.diff[lr.ineq==i & treat==1])))
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}
as.matrix(paste(results[,1], " & ", results[,2], " & (", results[,6], ") & ", results[,3], " & (", results[,7], ") & ", results[,4], " & ", results[,5], sep=""))

# FIGURE A.33
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,4), ylim = c(min(results[,2:3]), max(results[,2:3])), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "Approval Differential in Favor of Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
   axis(2)
   axis(3, median, labels=c("Median")) 
   
   abline(h = 0, col='grey60', lty=1, lwd=1) 
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,5, legend.text, lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.ineq, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_33_w5_ineq_effects_approval.eps")
plot.it()
dev.off()

###############################################################################
# C.1.6 MODEL-BASED ESTIMATES
###############################################################################

# TREATMENT CONDITIONS: 0: LD+ v RD+"; "1: LD- v RD+"; "NA: RD- v RD+";
treat <- ifelse(t1.treat==3 | t1.treat==4, 0, NA) 
treat <- ifelse(t1.treat==5 | t1.treat==6, 1, treat) 
table(treat)

# VOTE FOR CANDIDATE 2
vote.c2 <- ifelse(T1<=2, T1, NA)
vote.c2 <- vote.c2-1
table(vote.c2)
tapply(vote.c2, list(treat), mean, na.rm = TRUE)

lr.ineq <- ifelse(ID7<=4, ID7, NA)

# ESTIMATE THE LOGIT
est.logit <- glm(vote.c2 ~ treat + lr.ineq, family=binomial(link="logit"), na.action=na.omit) 
summary(est.logit)

# TABLE A.33: LOGIT ESTIMATES
logit.sum <- summary(est.logit)
est.logit.coef <- coef(summary(est.logit))
est.logit.table1 <- round(cbind(est.logit.coef[,c(1,2,4)], confint(est.logit, level = 0.95), confint(est.logit, level = 0.99)), 3)
est.logit.table1

length(est.logit$y)
round(logLik(est.logit), 3)

# COMPUTE CIs FOR MODEL MODEL PARAMETERS VIA SIMULATION
library(arm)
n.sims <- 100000
logit.sims <- sim(est.logit, n.sims)
beta.sims <- coef(logit.sims)
b0.sim <- beta.sims[,1]
b1.sim <- beta.sims[,2]
b2.sim <- beta.sims[,3]
b0 <- mean(b0.sim)
b1 <- mean(b1.sim)
b2 <- mean(b2.sim)

# THE T1 SWING VOTER
xM <- -b0.sim/b2.sim
xM.table <- round(c(mean(xM), sd(xM), quantile(xM, c(.025,.975))), 3)
xM.table <- paste(xM.table[1], " & ", xM.table[2], " & (", xM.table[3], ", ", xM.table[4], ")", sep="")

# CANDIDATE POSITIONS
xL <- -b0.sim/b2.sim - b2.sim/4
xR <- -b0.sim/b2.sim + b2.sim/4
xL.table <- round(c(mean(xL), sd(xL), quantile(xL, c(.025,.975))), 3)
xL.table <- paste(xL.table[1], " & ", xL.table[2], " & (", xL.table[3], ", ", xL.table[4], ")", sep="")
xR.table <- round(c(mean(xR), sd(xR), quantile(xR, c(.025,.975))), 3)
xR.table <- paste(xR.table[1], " & ", xR.table[2], " & (", xR.table[3], ", ", xR.table[4], ")", sep="")

# MANIPULATION PENALTY
mu1 <- b1.sim
mu1.table <- round(c(mean(mu1), sd(mu1), quantile(mu1, c(.025,.975))), 3)
mu1.table <- paste(mu1.table[1], " & ", mu1.table[2], " & (", mu1.table[3], ", ", mu1.table[4], ")", sep="")

# THE T2 SWING VOTER
xS <-  -(b0.sim+b1.sim)/b2.sim
xS.table <- round(c(mean(xS), sd(xS), quantile(xS, c(.025,.975))), 3)
xS.table <- paste(xS.table[1], " & ", xS.table[2], " & (", xS.table[3], ", ", xS.table[4], ")", sep="")

est.logit.table2 <- rbind(mu1.table, xM.table, xS.table, xL.table, xR.table)
rownames(est.logit.table2) <- c("delta", "xM",  "xS", "xL", "xR")
colnames(est.logit.table2) <- c("mean", "se", "2.5%, 97.5%")
est.logit.table2

# FIGURE A.34
xSmu <- mean(xS)
xS.plot <- mean(xM)
xM.plot <- median(lr.ineq, na.rm=TRUE)
xL <- mean(xL)
xR <- mean(xR)
lr.plot <- seq(1,4,.01)

# CIs
upper95 <-c()
lower05 <-c()
for (i in 1:length(lr.plot)) {
   upper95 <- c(upper95, quantile(invlogit(b0.sim + b2.sim*lr.plot[i]), .975))
   lower05 <- c(lower05, quantile(invlogit(b0.sim + b2.sim*lr.plot[i]), .025))
}

upper95.t1 <-c()
lower05.t1 <-c()
for (i in 1:length(lr.plot)) {
   upper95.t1 <- c(upper95.t1, quantile(invlogit(b0.sim + b1.sim + b2.sim*lr.plot[i]), .975))
   lower05.t1 <- c(lower05.t1, quantile(invlogit(b0.sim + b1.sim + b2.sim*lr.plot[i]), .025))
}


# PLOT LOGIT PREDICTIONS 
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   xvalues <- as.numeric(names(table(lr.self)))
   plot(NA, xlim = c(1, 4), ylim = c(0, 1), xlab = "Left-Right Self-Placement", ylab = "Probability of Voting for the Candidate on the Right", xaxt = "n", yaxt = "n")

   axis(1, seq(1, 4))
   axis(2, seq(0,1,.25)) 
   axis(3, at=c(xM.plot, xS.plot, xSmu), labels=c(expression(paste(x[M], "")), expression(paste("", x[S](0))), expression(paste("", x[S](mu)))))

   polygon(c(lr.plot, rev(lr.plot)), c(lower05.t1, rev(upper95.t1)), col='grey90', border=NA)
   abline(h = 0.5, col='grey60', lty=1, lwd=1)

   curve(invlogit(b0 + b2*x), add=TRUE, lty=1, col = "black", lwd=2)
   curve(invlogit(b0 + b1 + b2*x), add=TRUE, lty=2, col = "red", lwd=2) 

   #rug(jitter(lr.plot, amount = .1))
   legend(1,.95, c("LD+ v. RD+", "LD- v. RD+"), lty=c(1,2), lwd=c(2,2), col=c("black","red")) 
}

x11(width = 8, height = 6)
plot.it()
setEPS(width = 8, height = 6)
postscript("FIGURES/app_figure_34_logit_ineq.eps")
plot.it()
dev.off()

###############################################################################
# D.1 CANDIDATE CHOICE EXPERIMENT II
###############################################################################

# COMPARE TREATMENT CONDITIONS: "T1: RD+ v LD+"; "T2: RD- v LD+"; "T3: LD- v LD+";
treat <- ifelse(t4.treat==1, 1, NA) 
treat <- ifelse(t4.treat==2, 3, treat) 
treat <- ifelse(t4.treat==3, 2, treat) 

# TABLE A.34

vote.c2 <- ifelse(T4<=2, T4, NA)
vote.c2 <- vote.c2-1

c2s <- c(sum(vote.c2[treat==1], na.rm=TRUE), sum(vote.c2[treat==2], na.rm=TRUE), sum(vote.c2[treat==3], na.rm=TRUE))
totals <- c(sum(!is.na(vote.c2[treat==1])), sum(!is.na(vote.c2[treat==2])), sum(!is.na(vote.c2[treat==3])))

# "T1: RD+ v LD+"
test <- prop.test(c2s[1], totals[1])
test
round(100*test$estimate, 2)
round(100*test$conf.int, 2)

# "T2: RD- v LD+"
test <- prop.test(c2s[2], totals[2])
round(100*test$estimate, 2)
round(100*test$conf.int, 2)

# "T3: LD- v LD+"
test <- prop.test(c2s[3], totals[3])
round(100*test$estimate, 2)
round(100*test$conf.int, 2)

# COMPARE TREATMENT CONDITIONS 1 AND 2 ("1: RD+ v LD+"; "2: RD- v LD+"): VOTE FOR C2
c2s <- c(sum(vote.c2[treat==1], na.rm=TRUE), sum(vote.c2[treat==2], na.rm=TRUE))
totals <- c(sum(!is.na(vote.c2[treat==1])), sum(!is.na(vote.c2[treat==2])))
prop.test(c2s, totals)
prop.test(c2s, totals)$estimate[1]-prop.test(c2s, totals)$estimate[2]        
  
# COMPARE TREATMENT CONDITIONS 3 AND 2 ("3: LD- v LD+"; "2: RD- v LD+"): VOTE FOR C2
c2s <- c(sum(vote.c2[treat==3], na.rm=TRUE), sum(vote.c2[treat==2], na.rm=TRUE))
totals <- c(sum(!is.na(vote.c2[treat==3])), sum(!is.na(vote.c2[treat==2])))
prop.test(c2s, totals)
prop.test(c2s, totals)$estimate[1]-prop.test(c2s, totals)$estimate[2]        

# TABLE A.35

# APPROVAL OF C1
app.c1 <- ifelse(T5<=10, T5, NA)
round(tapply(app.c1, list(treat), mean, na.rm = TRUE),2)

# APPROVAL OF C2
app.c2 <- ifelse(T6<=10, T6, NA)
round(tapply(app.c2, list(treat), mean, na.rm = TRUE), 2)

# C2-C1
app.diff <- app.c2-app.c1
round(tapply(app.diff, list(treat), mean, na.rm = TRUE), 2)

# CONFIDENCE INTERVALS FOR THE DIFFERENCE
test <- t.test(app.diff[treat==1])
round(test$conf.int, 2)
test <- t.test(app.diff[treat==2])
round(test$conf.int, 2)
test <- t.test(app.diff[treat==3])
round(test$conf.int, 2)

test <- t.test(app.diff[treat==1], app.diff[treat==2])
test 
round(test$conf.int, 2)

test <- t.test(app.diff[treat==3], app.diff[treat==2])
test 
round(test$conf.int, 2)

# HETEROGENEITY BY SELF-PLACEMENT AND ATTITUDES TOWARD INEQUALITY
lr.self <- ifelse(ID6d<=10, ID6d, NA)
C2.shares <- tapply(vote.c2, list(lr.self ,treat), mean, na.rm = TRUE)
C2.shares

lr.ineq <- ifelse(ID7<=4, ID7, NA)
C2.shares <- tapply(vote.c2, list(lr.ineq ,treat), mean, na.rm = TRUE)
C2.shares
