rm(list=ls(all=TRUE))
set.seed(77)

# CHANGE PATH TO THE REPLICATION FOLDER HERE!
path1 <-"C:/Users/ms3295/Dropbox/Hypo/Work/Current Projects/Polarization and Fraud/Venezuela/Data Analysis/main/REPLICATION/"
setwd(path1)

###############################################################################
# INSTALL PACKAGES THAT WILL BE USED LATER
###############################################################################

install.packages("PACKAGES/arm_1.10-1.tar.gz", repo=NULL, type="source")
install.packages("PACKAGES/boot_1.3-23.tar.gz", repo=NULL, type="source")

library(arm)
library(boot)

###############################################################################
# INTRODUCTION
###############################################################################

# LOAD DATA
data <- read.csv(file="DATA/backsliding.csv", header=TRUE, sep=",")
attach(data)

# BASIC SUMMARIES
length(mode)
table(mode)

# COUNT COUPS VERSUS TAKEOVERS IN THE BREAKDOWNS DATA
coups  <- c()
takeovers <- c()
for (i in 1:5) {
    mode[(year>=1960 + 10*i) & (year<=1969 + 10*i)]
    coups  <- c(coups, sum(mode[(year>=1960 + 10*i) & (year<=1969 + 10*i)]=="military coup"))
    takeovers <- c(takeovers, sum(mode[(year>=1960 + 10*i) & (year<=1969 + 10*i)]=="executive takeover"))
}

# TABLE 1
coups
takeovers

# P-VALUES FOR THE ONE-SIDED NULL HYPOTHESIS THAT COUPD AND EXECUTIVE TAKEOVERS ARE EQUALLY LIKELY
for (i in 1:5) {
    test <- binom.test(takeovers[i], takeovers[i] + coups[i], p=1/2, alternative="greater")
    print(round(test$p.value, 3))
}

rm(data, test)

###############################################################################
# THE CANDIDATE CHOICE EXPERIMENT
###############################################################################

# LOAD DATA
data <- read.csv(file="DATA/survey.csv", header=TRUE, sep=",")
attach(data)


###############################################################################
# SECTION 2.1 Across-Subject Treatment Assignments
###############################################################################

# TABLE 2
# COMPARE TREATMENT CONDITIONS: "T1: LD+ v RD+"; "T2: LD- v RD+"; "T3: RD- v RD+";
treat <- ifelse(t1.treat==1 | t1.treat==2, 3, NA) 
treat <- ifelse(t1.treat==3 | t1.treat==4, 1, treat) 
treat <- ifelse(t1.treat==5 | t1.treat==6, 2, treat) 

vote.c2 <- ifelse(T1<=2, T1, NA)
vote.c2 <- vote.c2-1

c2s <- c(sum(vote.c2[treat==1], na.rm=TRUE), sum(vote.c2[treat==2], na.rm=TRUE), sum(vote.c2[treat==3], na.rm=TRUE))
totals <- c(sum(!is.na(vote.c2[treat==1])), sum(!is.na(vote.c2[treat==2])), sum(!is.na(vote.c2[treat==3])))

# "T1: LD+ v RD+"
test <- prop.test(c2s[1], totals[1])
test
round(100*test$estimate, 2)
round(100*test$conf.int, 2)

# "T2: LD- v RD+"
test <- prop.test(c2s[2], totals[2])
round(100*test$estimate, 2)
round(100*test$conf.int, 2)

# "T3: RD- v RD+"
test <- prop.test(c2s[3], totals[3])
round(100*test$estimate, 2)
round(100*test$conf.int, 2)

# COMPARE TREATMENT CONDITIONS 1 AND 2 ("1: LD+ v RD+"; "2: LD- v RD+"): VOTE FOR C2
c2s <- c(sum(vote.c2[treat==1], na.rm=TRUE), sum(vote.c2[treat==2], na.rm=TRUE))
totals <- c(sum(!is.na(vote.c2[treat==1])), sum(!is.na(vote.c2[treat==2])))
prop.test(c2s, totals)
prop.test(c2s, totals)$estimate[1]-prop.test(c2s, totals)$estimate[2]        

     
# COMPARE TREATMENT CONDITIONS 3 AND 2 ("3: RD- v RD+"; "2: LD- v RD+"): VOTE FOR C2
c2s <- c(sum(vote.c2[treat==3], na.rm=TRUE), sum(vote.c2[treat==2], na.rm=TRUE))
totals <- c(sum(!is.na(vote.c2[treat==3])), sum(!is.na(vote.c2[treat==2])))
prop.test(c2s, totals)
prop.test(c2s, totals)$estimate[1]-prop.test(c2s, totals)$estimate[2]        

# THE LEFT-RIGHT SELF-PLACEMENT SCALE
lr.self <- ifelse(ID6d<=10, ID6d, NA)

# THE CI FOR THE MEDIAN OF THE LEFT-RIGHT SELF-PLACEMENT SCALE
median <- median(lr.self, na.rm=TRUE) 
boot.ci(boot(na.omit(lr.self), function(x,i) median(x[i]), R=10000))

# FIGURE 1: THE HISTOGRAM OF THE LEFT-RIGHT SELF-PLACEMENT SCALE
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   hist(lr.self, breaks=seq(0,10), xlab = "Left-Right Self-Placement", ylab = "Frequency", xaxt = "n", main="")
   axis(1, at=.5:9.5, labels=1:10)
   abline(v = 6.5, col = "red", lty=1, lwd=2)
   legend(.5, 275, c("median, 95% CI: 6-8 "),  lty=c(1), lwd=c(2), col=c("red")) 
}
 
x11(width = 8, height = 6)
plot.it()
dev.print(png, filename="FIGURES/paper_figure_1_lr_histogram.png", width=800, height=600)

# PRINT FOR THE PAPER
setEPS(width = 8, height = 6)
postscript("FIGURES/paper_figure_1_lr_histogram.eps")
plot.it()
dev.off()

# FIGURE 2: THE PLOT BASED ON THE LEFT-RIGHT SELF-PLACEMENT SCALE
# A PLOT THAT COMBINES ALL THREE TREATMENT CONDITIONS

C2.shares <- tapply(vote.c2, list(lr.self ,treat), mean, na.rm = TRUE)

# PLOT
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(-0.1, 1.1), xlab = "Left-Right Self-Placement Scale", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(3, median, labels=c("Median")) 
   axis(2, seq(0,1,.25)) 
   abline(h = 0.5, col='grey60', lty=1, lwd=1)
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(C2.shares[,1], pch = 19, col = "black", bg = "black", cex=1)
   lines(C2.shares[,1], type="l", lty=1, col = "black", lwd=1) 

   points(C2.shares[,2], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(C2.shares[,2], type="l", lty=2, col = "red", lwd=1) 

   points(C2.shares[,3], pch = 17, col = "blue", bg = "blue", cex=1.2)
   lines(C2.shares[,3], type="l", lty=3, col = "blue", lwd=1) 
   
   legend(1,1, c("T1: LD+ v. RD+", "T2: LD- v. RD+", "T3: RD- v. RD+"), lty=c(1,2,3), lwd=c(2,2,2), pch=c(19,18,17), col=c("black","red","blue")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
dev.print(png, filename="FIGURES/paper_figure_2_lr_effects_all.png", width=800, height=600)
setEPS(width = 8, height = 6)
postscript("FIGURES/paper_figure_2_lr_effects_all.eps")
plot.it()
dev.off()

# ATTITUDES TOWARD INEQUALITY
lr.ineq <- ifelse(ID7<=4, ID7, NA)

# THE CI FOR THE MEDIAN OF LR
median <- median(lr.ineq, na.rm=TRUE) 
boot.ci(boot(na.omit(lr.ineq), function(x,i) median(x[i]), R=10000))

plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   hist(lr.ineq, breaks=seq(0,4), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "Frequency", xaxt = "n", main="")
   axis(1, at=.5:3.5, labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
   abline(v = 2.5, col = "red", lty=1, lwd=2)
   legend(.15, 285, c("median, 95% CI: 2-3 "),  lty=c(1), lwd=c(2), col=c("red")) 
}
 
x11(width = 8, height = 6)
plot.it()
dev.print(png, filename="FIGURES/paper_figure_1_ineq_histogram.png", width=800, height=600)
setEPS(width = 8, height = 6)
postscript("FIGURES/paper_figure_1_ineq_histogram.eps")
plot.it()
dev.off()

# FIGURE 2: THE PLOT BASED ON THE LEFT-RIGHT SELF-PLACEMENT SCALE
# A PLOT THAT COMBINES ALL THREE TREATMENT CONDITIONS

C2.shares <- tapply(vote.c2, list(lr.ineq ,treat), mean, na.rm = TRUE)

# PLOT
median <- median(lr.ineq, na.rm=TRUE)
plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,4), ylim = c(-0.1, 1.1), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
   axis(3, 3, labels=c("Median")) 
   axis(2, seq(0,1,.25)) 
   abline(h = 0.5, col='grey60', lty=1, lwd=1)
   abline(v = 3, col='grey60', lty=2, lwd=1)
         
   points(C2.shares[,1], pch = 19, col = "black", bg = "black", cex=1)
   lines(C2.shares[,1], type="l", lty=1, col = "black", lwd=1) 

   points(C2.shares[,2], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(C2.shares[,2], type="l", lty=2, col = "red", lwd=1) 

   points(C2.shares[,3], pch = 17, col = "blue", bg = "blue", cex=1.2)
   lines(C2.shares[,3], type="l", lty=3, col = "blue", lwd=1) 
   
   legend(1,1, c("T1: LD+ v. RD+", "T2: LD- v. RD+", "T3: RD- v. RD+"), lty=c(1,2,3), lwd=c(2,2,2), pch=c(19,18,17), col=c("black","red","blue")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
dev.print(png, filename="FIGURES/paper_figure_2_ineq_effects_all.png", width=800, height=600)
setEPS(width = 8, height = 6)
postscript("FIGURES/paper_figure_2_ineq_effects_all.eps")
plot.it()
dev.off()

###############################################################################
# SECTION 2.2 Within-Subject Treatment Assignments
###############################################################################

# TREATMENT CONDITIONS: "T1: LD+ v RD+"; "W1: LD- v. RD+"
t.cond <- t1.treat==3

# VOTE FOR C2 IN THE CONTROL CONDITION
vote.c <- ifelse(T1==2, 1, NA)
vote.c <- ifelse(T1==1, 0, vote.c)
vote.c[t.cond]

# VOTE FOR C2 IN TREATMENT (FOLLOW-UP)
vote.t <- ifelse(T1a==2, 1, NA)
vote.t <- ifelse(T1a==1, 0, vote.t)
vote.t[t.cond]

n <- length(vote.c[t.cond])
vote.c2 <- c(vote.c[t.cond], vote.t[t.cond])
treat <- c(rep(0,n), rep(1,n))

# VOTE FOR C2: AGGREGATE ANALYSIS
result <- tapply(vote.c2, list(treat), mean, na.rm = TRUE)
round(100*result, 2)
result[1]-result[2]
c2s <- c(sum(vote.c2[treat==0], na.rm=TRUE), sum(vote.c2[treat==1], na.rm=TRUE))
totals <- c(sum(!is.na(vote.c2[treat==0])), sum(!is.na(vote.c2[treat==1])))

test <- prop.test(c2s, totals)
test
round(test$p.value, 3)
round(100*test$estimate, 2)
round(100*test$conf.int, 2)

# FIGURE 3: THE PLOT BASED ON THE LEFT-RIGHT SELF-PLACEMENT SCALE
lr.self <- ifelse(ID6d<=10, ID6d, NA)
lr.self <- c(lr.self[t.cond], lr.self[t.cond])
tapply(vote.c2, list(lr.self ,treat), mean, na.rm = TRUE)

results <- c()
for (i in 1:10) {
    c2s <- c(sum(vote.c2[lr.self==i & treat==0]==1, na.rm=TRUE), sum(vote.c2[lr.self==i & treat==1]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.self==i & treat==0])), sum(!is.na(vote.c2[lr.self==i & treat==1])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.self", "control", "treat", "diff", "p.value", "N1", "N2")
}

plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   plot(NA, xlim = c(1,10), ylim = c(-0.1, 1.1), xlab = "Left-Right Self-Placement Scale", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

   axis(1, seq(1,10)) 
   axis(3, median, labels=c("Median")) 
   axis(2, seq(0,1,.25)) 
   abline(h = 0.5, col='grey60', lty=1, lwd=1)
   abline(v = median, col='grey60', lty=2, lwd=1)
       
   points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
   lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

   points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
   lines(results[,3], type="l", lty=2, col = "red", lwd=1) 
   
   legend(1,1, c("T1: LD+ v. RD+", "W1: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red")) 
}

median <- median(lr.self, na.rm=TRUE)
x11(width = 8, height = 6)
plot.it()
dev.print(png, filename="FIGURES/paper_figure_3_w1_lr_effects.png", width=800, height=600)
setEPS(width = 8, height = 6)
postscript("FIGURES/paper_figure_3_w1_lr_effects.eps")
plot.it()
dev.off()

# FIGURE 3: THE PLOT BASED ON BY ATTITUDES TOWARD INEQUALITY
lr.ineq <- ifelse(ID7<=4, ID7, NA)
lr.ineq <- c(lr.ineq[t.cond], lr.ineq[t.cond])

results <- c()
for (i in 1:4) {
    c2s <- c(sum(vote.c2[lr.ineq==i & treat==0]==1, na.rm=TRUE), sum(vote.c2[lr.ineq==i & treat==1]==1, na.rm=TRUE))
    totals <- c(sum(!is.na(vote.c2[lr.ineq==i & treat==0])), sum(!is.na(vote.c2[lr.ineq==i & treat==1])))
    test <- prop.test(c2s, totals)
    result <- c(i, round(test$estimate,4), round(test$estimate[2]-test$estimate[1], 4), round(test$p.value,3), totals)
    results <- rbind(results, result)
    colnames(results) <- c("lr.ineq", "control", "treat", "diff", "p.value", "N1", "N2")
}

# PLOT
median <- median(lr.ineq, na.rm=TRUE)
plot.it <- function() {
  par(mar=c(5,6,2,2)+0.1)
  plot(NA, xlim = c(1,4), ylim = c(-0.1, 1.1), xlab = "Government Should Reduce Inequalities between the Rich and the Poor", ylab = "% Vote Share for Candidate 2",  yaxt = "n",  xaxt = "n")

  axis(1, seq(1,4), labels=c("Strongly \n Agree", "Somewhat \n Agree", "Somewhat \n Disagree", "Strongly \n Disagree"), cex.axis=.75) 
  axis(3, 3, labels=c("Median")) 
  axis(2, seq(0,1,.25)) 
  abline(h = 0.5, col='grey60', lty=1, lwd=1)
  abline(v = 3, col='grey60', lty=2, lwd=1)
      
  points(results[,2], pch = 19, col = "black", bg = "black", cex=1)
  lines(results[,2], type="l", lty=1, col = "black", lwd=1) 

  points(results[,3], pch = 18, col = "red", bg = "red", cex=1.2)
  lines(results[,3], type="l", lty=2, col = "red", lwd=1) 

  legend(1,1, c("T1: LD+ v. RD+", "W1: LD- v. RD+"), lty=c(1,2), lwd=c(2,2), pch=c(19,18), col=c("black","red"))   
}

x11(width = 8, height = 6)
plot.it()
dev.print(png, filename="FIGURES/paper_figure_3_w1_ineq_effects.png", width=800, height=600)
setEPS(width = 8, height = 6)
postscript("FIGURES/paper_figure_3_w1_ineq_effects.eps")
plot.it()
dev.off()

###############################################################################
# SECTION 2.3 Model-based Estimates
###############################################################################

# TREATMENT CONDITIONS: 0: LD+ v RD+"; "1: LD- v RD+"; "NA: RD- v RD+";
treat <- ifelse(t1.treat==3 | t1.treat==4, 0, NA) 
treat <- ifelse(t1.treat==5 | t1.treat==6, 1, treat) 

# VOTE FOR CANDIDATE 2
vote.c2 <- ifelse(T1<=2, T1, NA)
vote.c2 <- vote.c2-1

# L-R SELF-PLACEMENT
lr.self <- ifelse(ID6d<=10, ID6d, NA)

# ESTIMATE THE LOGIT
est.logit <- glm(vote.c2 ~ treat + lr.self, family=binomial(link="logit"), na.action=na.omit) 
summary(est.logit)

# TABLE 3: LOGIT ESTIMATES
logit.sum <- summary(est.logit)
est.logit.coef <- coef(summary(est.logit))
est.logit.table1 <- round(cbind(est.logit.coef[,c(1,2,4)], confint(est.logit, level = 0.95), confint(est.logit, level = 0.99)), 3)
est.logit.table1

length(est.logit$y)
round(logLik(est.logit), 3)

# COMPUTE CIs FOR MODEL MODEL PARAMETERS VIA SIMULATION
library(arm)
n.sims <- 100000
logit.sims <- sim(est.logit, n.sims)
beta.sims <- coef(logit.sims)
b0.sim <- beta.sims[,1]
b1.sim <- beta.sims[,2]
b2.sim <- beta.sims[,3]
b0 <- mean(b0.sim)
b1 <- mean(b1.sim)
b2 <- mean(b2.sim)

# THE T1 SWING VOTER
xM <- -b0.sim/b2.sim
xM.table <- round(c(mean(xM), sd(xM), quantile(xM, c(.025,.975))), 3)
xM.table <- paste(xM.table[1], " & ", xM.table[2], " & (", xM.table[3], ", ", xM.table[4], ")", sep="")

# CANDIDATE POSITIONS
xL <- -b0.sim/b2.sim - b2.sim/4
xR <- -b0.sim/b2.sim + b2.sim/4
xL.table <- round(c(mean(xL), sd(xL), quantile(xL, c(.025,.975))), 3)
xL.table <- paste(xL.table[1], " & ", xL.table[2], " & (", xL.table[3], ", ", xL.table[4], ")", sep="")
xR.table <- round(c(mean(xR), sd(xR), quantile(xR, c(.025,.975))), 3)
xR.table <- paste(xR.table[1], " & ", xR.table[2], " & (", xR.table[3], ", ", xR.table[4], ")", sep="")

# MANIPULATION PENALTY
mu1 <- b1.sim
mu1.table <- round(c(mean(mu1), sd(mu1), quantile(mu1, c(.025,.975))), 3)
mu1.table <- paste(mu1.table[1], " & ", mu1.table[2], " & (", mu1.table[3], ", ", mu1.table[4], ")", sep="")

# THE T2 SWING VOTER
xS <-  -(b0.sim+b1.sim)/b2.sim
xS.table <- round(c(mean(xS), sd(xS), quantile(xS, c(.025,.975))), 3)
xS.table <- paste(xS.table[1], " & ", xS.table[2], " & (", xS.table[3], ", ", xS.table[4], ")", sep="")

# TABLE 3: MODEL PARAMETERS
est.logit.table2 <- rbind(mu1.table, xL.table, xR.table, xM.table, xS.table)
rownames(est.logit.table2) <- c("delta", "xL", "xR", "xS(0)", "xS(mu)")
colnames(est.logit.table2) <- c("mean      se      (2.5%, 97.5%)")
est.logit.table2

# FIGURE 4: PLOT LOGIT PREDICTIONS 
xSmu <- mean(xS)
xS <- mean(xM)
xM <- median(lr.self, na.rm=TRUE)
xL <- mean(xL)
xR <- mean(xR)
lr.plot <- seq(1,10,.01)

# CIs
upper95 <-c()
lower05 <-c()
for (i in 1:length(lr.plot)) {
   upper95 <- c(upper95, quantile(invlogit(b0.sim + b2.sim*lr.plot[i]), .975))
   lower05 <- c(lower05, quantile(invlogit(b0.sim + b2.sim*lr.plot[i]), .025))
}

upper95.t1 <-c()
lower05.t1 <-c()
for (i in 1:length(lr.plot)) {
   upper95.t1 <- c(upper95.t1, quantile(invlogit(b0.sim + b1.sim + b2.sim*lr.plot[i]), .975))
   lower05.t1 <- c(lower05.t1, quantile(invlogit(b0.sim + b1.sim + b2.sim*lr.plot[i]), .025))
}

plot.it <- function() {
   par(mar=c(5,6,2,2)+0.1)
   xvalues <- as.numeric(names(table(lr.self)))
   plot(NA, xlim = c(1, 10), ylim = c(0, 1), xlab = "Left-Right Self-Placement", ylab = "Probability of Voting for the Candidate on the Right", xaxt = "n", yaxt = "n")

   axis(1, seq(1, 10))
   axis(2, seq(0,1,.25)) 
   axis(3, at=c(xM, xS, xSmu), labels=c(expression(paste(x[M], "")), expression(paste("", x[S](0))), expression(paste("", x[S](mu)))))

   polygon(c(lr.plot, rev(lr.plot)), c(lower05.t1, rev(upper95.t1)), col='grey90', border=NA)
   abline(h = 0.5, col='grey60', lty=1, lwd=1)

   curve(invlogit(b0 + b2*x), add=TRUE, lty=1, col = "black", lwd=2)
   curve(invlogit(b0 + b1 + b2*x), add=TRUE, lty=2, col = "red", lwd=2) 

   #rug(jitter(lr.plot, amount = .1))
   legend(1,.95, c("LD+ v. RD+", "LD- v. RD+"), lty=c(1,2), lwd=c(2,2), col=c("black","red")) 
}

x11(width = 8, height = 6)
plot.it()
dev.print(png, filename="FIGURES/paper_figure_4_logit_lr.png", width=800, height=600)
setEPS(width = 8, height = 6)
postscript("FIGURES/paper_figure_4_logit_lr.eps")
plot.it()
dev.off()

# FRACTION OF THE SAMPLE TO DEFECTING FROM C2 WHEN HE IS D- = THE FRACTION OF THE SAMPLE BETWEEN THE SWING VOTERS
cdf.lr <- ecdf(lr.self)
round(100*(cdf.lr(xS)- cdf.lr(xSmu)),2)

# THE FRACTION OF THE SAMPLE TO THE LEFT OF THE SWING VOTER IN "LD+ v RD+"
round(100*(cdf.lr(xS)),2)
# THE FRACTION OF THE SAMPLE TO THE LEFT OF THE SWING VOTER IN "LD- v RD+"
round(100*(cdf.lr(xSmu)),2)
# FRACTION OF PARTISANS FIRST TO THE LEFT OF THE SWING VOTER IN "LD+ v RD+"
round(100*(cdf.lr(xSmu)/cdf.lr(xS)),2)
# FRACTION OF DEMOCRATS FIRST TO THE LEFT OF THE SWING VOTER IN "LD+ v RD+"
round(100*((cdf.lr(xS) - cdf.lr(xSmu))/cdf.lr(xS)),2)

###############################################################################
# SECTION 2.4 Support for Democracy
###############################################################################

# L-R SELF-PLACEMENT
lr.self <- ifelse(ID6d<=10, ID6d, NA)

# VOTE: RIGHT IS 1; LEFT IS 0
vote.c <- ifelse(T1==2, 1, NA)
vote.c <- ifelse(T1==1, 0, vote.c)

# USE LOGIT TO FIND THE CATEGORY OF L-R FOR WHICH VOTERS ARE INDIFFERENT BETWEEN CANDIDATES UNDER THE CONTROL CONDITION "LD+ v RD+"
treatment.c <- ifelse(t1.treat==3 | t1.treat==4, 0, NA)
est.logit <- glm(vote.c[treatment.c==0] ~ lr.self[treatment.c==0], family=binomial(link="logit"), na.action=na.omit) 
summary(est.logit)

# COMPUTE CIs FOR MODEL MODEL PARAMETERS VIA SIMULATION
library(arm)
n.sims <- 100000
logit.sims <- sim(est.logit, n.sims)
beta.sims <- coef(logit.sims)
b0 <- beta.sims[,1]
b1 <- beta.sims[,2]

# THE MEDIAN
xM <- -b0/b1
xM <- mean(xM)
xM <- round(xM)

# FOR THOSE TO THE LEFT OF xM, VOTING D+ GOES AGAINST THEIR ECONOMIC INTEREST IN "LD- v RD+"
treatment.w1 <- ifelse(t1.treat==3, 1, NA)
# VOTING D+ IN "LD- v RD+" MEANS VOTING FOR C2
vote.w1 <- ifelse(T1a==2, 1, NA)
vote.w1 <- ifelse(T1a==1, 0, vote.w1)
vote.w1 <- ifelse(treatment.w1==1, vote.w1, NA)

# FOR THOSE TO THE RIGHT OF xM, VOTING D+ GOES AGAINST THEIR ECONOMIC INTEREST IN "LD+ v RD-"
treatment.w2 <- ifelse(t1.treat==4, 1, NA)
# VOTING D+ IN "LD+ v RD-" MEANS VOTING FOR C1
vote.w2 <- ifelse(T1a==1, 1, NA)
vote.w2 <- ifelse(T1a==2, 0, vote.w2)
vote.w2 <- ifelse(treatment.w2==1, vote.w2, NA)

# WHEN VOTING FOR D+ GO AGAINST YOUR INTEREST: DO YOU VOTE D+? 
mean(c(vote.w1[lr.self<=xM], vote.w2[lr.self>xM]), na.rm=TRUE)

# SUPPORT FOR DEMOCRACY: "1" CORRESPONDS TO THE STRONGEST FORM OF SUPPORT
dem.support <- ifelse(DA1>5, NA, DA1)
vote.dem  <- c(vote.w1[lr.self<=xM], vote.w2[lr.self>xM])
d.support <- c(dem.support[lr.self<=xM], dem.support[lr.self>xM])
counts <- table(d.support)
percent.support <- 100*counts/sum(counts)

mean <- tapply(vote.dem, list(d.support), mean, na.rm = TRUE)
mean

vote.dem.plot <- mean*percent.support
vote.undem.plot <- (1-mean)*percent.support

# FIGURE 5:  SUPPORT FOR DEMOCRACY AS MEASURED BY AGREEMENT WITH THE STATEMENT ``DEMOCRACY MAY HAVE PROBLEMS BUT IT IS THE BEST SYSTEM OF GOVERNMENT '' VERSUS VOTING FOR THE MORE DEMOCRATIC CANDIDATE IN THE CANDIDATE-CHOICE EXPERIMENT
plot.it <- function() {
    par(mar=c(5,6,2,2)+0.1)
    bp <- barplot(rbind(vote.dem.plot,vote.undem.plot), main="\"Democracy may have problems, \n but it is the best system of government\"", 
        ylim = c(0, 80),
        xlab="", 
        ylab="",
        col=c("gray10", "gray70"),
        legend.text=c("Voted D+","Voted D-"),
        args.legend=list(x=5,y=70,bty = "y"),
        names.arg = c("Strongly \n Agree", "Somewhat \n Agree","Somewhat \n Disgree","Strongly \n Disgree", "Does Not \n Matter"))
    text(bp, percent.support + 5, paste(round(percent.support, 0),"%", sep=""), cex=1, pos=1)
}

x11(width = 8, height = 6)
plot.it()
dev.print(png, filename="FIGURES/paper_figure_5_demsupport2a.png", width=800, height=600)
setEPS(width = 8, height = 6)
postscript("FIGURES/paper_figure_5_demsupport2a.eps")
plot.it()
dev.off()

# PERCENT OF THOSE AGREEING NONETHELESS VOTING FOR D-
round(100*(1-mean(vote.dem[d.support<=2], na.rm=TRUE)))

# THE STRONGEST FORM OF DIRECTLY MEASURED SUPPORT FOR DEMOCRACY IS NO BETTER AT PREDICTING SUPPORT FOR THE MORE DEMOCRATIC CANDIDATE THAN THE FLIP OF A COIN
mean(vote.dem[d.support==1], na.rm=TRUE)

# FIGURE 5: THE MOST IMPORTANT ASPECT OF ``BOLIVARIAN DEMOCRACY'' VERSUS THE MOST IMPORTANT ASPECT OF DEMOCRACY FOR THE RESPONDENT

# BOLIVARIAN DEMOCRACY
table(DA2)
dem.bol <- ifelse(DA2>5, NA, DA2)
counts.bol <- table(dem.bol)
percent.bol <- 100*counts.bol/sum(counts.bol)

# MOST IMPORTANT ASPECT OF DEMOCRACY FOR YOU
table(DA3)
dem.you <- ifelse(DA3>5, NA, DA3)
counts.you <- table(dem.you)
percent.you <- 100*counts.you/sum(counts.you)

plot.it <- function() {
    par(mar=c(5,6,2,2)+0.1)
    bp <- barplot(rbind(percent.bol, percent.you), 
        main="", 
        ylim = c(0, 40),
        xlab="", 
        ylab="%",
        col=c("gray10", "gray70"),
        legend.text=c("Bolivarian democracy","most important aspect\nof democracy for you"),
        args.legend=list(x=15,y=40, bty = "n"),
        names.arg = c("Fair\nElections", "Reducing\nInequality","Freedom of\nExpression","Accountable\nGovernment", "Checks and\nBalances"),
        beside=TRUE)

    text(bp[1,], percent.bol + 2.5, paste(round(percent.bol, 0),"%", sep=""), cex=1, pos=1)
    text(bp[2,], percent.you + 2.5, paste(round(percent.you, 0),"%", sep=""), cex=1, pos=1)
}

x11(width = 8, height = 6)
plot.it()
dev.print(png, filename="FIGURES/paper_figure_5_demwhat.png", width=800, height=600)
setEPS(width = 8, height = 6)
postscript("FIGURES/paper_figure_5_demwhat.eps")
plot.it()
dev.off()
